/*
 *  ImgView  A simple image viewer
 *
 *  Copyright (C) 2013 Mats Peterson
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *  
 *  Please send any comments/bug reports to
 *  matsp888@yahoo.com  (Mats Peterson)
 */

#include <xsimple.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "common.h"
#include "../imgview.h"


static void errmsg(char *msg)
{
    message("XBM Error", msg, NULL);
}

XImage *readxbm(char *fname)
{
    XImage *img = NULL;
    unsigned char *buf = NULL, *bp;
    unsigned int w, h;
    int xhot, yhot;
    int r, i;

    r = XReadBitmapFileData(fname, &w, &h, &buf, &xhot, &yhot);
    if (r != BitmapSuccess) {
        switch (r) {
            case BitmapOpenFailed:
                errmsg("Couldn't open X bitmap");
                break;
            case BitmapFileInvalid:
                errmsg("Invalid X bitmap data");
                break;
            case BitmapNoMemory:
                errmsg("Not enough memory for X bitmap");
                break;
        }
        return NULL;
    }

    img = mkximage(w, h, 1, NULL);

    bp = buf; dp = (unsigned char *)img->data;

    for (i = 0; i < (w + 7) / 8 * h; i++) {
        unsigned char bits = *bp++;
        *dp++ = ((bits >> 7) & 0x01) | ((bits >> 5) & 0x02) |
                ((bits >> 3) & 0x04) | ((bits >> 1) & 0x08) |
                ((bits << 1) & 0x10) | ((bits << 3) & 0x20) |
                ((bits << 5) & 0x40) | ((bits << 7) & 0x80);
    }

    return img;
}
